@@ -16,17 +16,16 @@
 #include <Rcpp.h>
 
 // [[Rcpp::export]]
-Rcpp::IntegerVector iterate_recaman(int n,
-                                    int start,
-                                    int increment) {
+Rcpp::IntegerVector cpp_recaman(const int& n,
+                                const int& start,
+                                const int& increment) {
   int inc = 0;
-  Rcpp::IntegerVector x = {start};
-  Rcpp::IntegerVector xlist = {start};
-  for (int i = 1; i < n; i++) {
+  Rcpp::IntegerVector x = {start}, xlist = {start};
+  for (int i = 1; i < n; ++i) {
     Rcpp::checkUserInterrupt();
-    inc = inc + increment;
+    inc += increment;
     int newx = x[i - 1] - inc;
-    bool contains = std::find(xlist.begin(), xlist.end(), newx) != xlist.end();
+    const bool contains = std::find(xlist.begin(), xlist.end(), newx) != xlist.end();
     if (contains || newx <= 0) {
       newx = x[i - 1] + inc;
     }
